# Tnn-Pytorch
This repository contains the Rpe, Tno, Gtu and Tnn layers (wip) mentioned in [Toeplitz Neural Network for Sequence Modeling](https://openreview.net/forum?id=IxmWsm4xrua). The overall network structure is as follows:

![](./network.png)



## Install

```
$ pip install tnn-pytorch
```



## Usage

### Tno



## Recommended configuration



## Todo

- [ ] Tnn layer
- [ ] Tnn model
- [ ] Recommended configuration

